@@ -75,15 +75,19 @@ class Deck(collections.Counter):
         if not vtes.VTES:
             vtes.VTES.load()
         for cid, count in r["cards"].items():
+            count = int(count)
+            if count <= 0:
+                continue
             ret[vtes.VTES.amaranth[cid]] = count
         return ret
 
     @classmethod
     def from_vdb(cls, uid: str):
         """Fetch a deck from VDB."""
-        r = requests.get("https://vdb.smeea.casa/api/deck/" + uid)
+        r = requests.get("https://vdb.im/api/deck/" + uid)
         r.raise_for_status()
         r = r.json()
+        logger.debug("VDB replied: %s", r)
         ret = cls(id=uid, author=r.get("author", r.get("owner", None)))
         ret.name = r.get("name", None)
         ret.comments = r.get("description", "")
@@ -94,10 +98,46 @@ class Deck(collections.Counter):
         )
         if not vtes.VTES:
             vtes.VTES.load()
-        for cid, data in itertools.chain(r["crypt"].items(), r["library"].items()):
-            ret[vtes.VTES[int(cid)]] = data["q"]
+        for cid, count in r["cards"].items():
+            count = int(count)
+            if count <= 0:
+                continue
+            ret[vtes.VTES[int(cid)]] = count
         return ret
 
+    @classmethod
+    def from_url(cls, url: str):
+        """Fetch from any deckbuilding website"""
+        result = urllib.parse.urlparse(url)
+        if result.netloc == "amaranth.vtes.co.nz":
+            if result.fragment.startswith("deck/"):
+                return cls.from_amaranth(result.fragment[5:])
+            raise ValueError("Unknown Amaranth URL format")
+        elif result.netloc in {"vdb.smeea.casa", "vdb.im"}:
+            if not result.path.startswith("/decks"):
+                raise ValueError("Unknown VDB URL path")
+            params = urllib.parse.parse_qs(result.query)
+            if "id" in params:
+                return cls.from_vdb(params["id"][0])
+            elif result.fragment:
+                ret = cls()
+                ret.name = params.get("name", None)
+                ret.author = params.get("author", None)
+                ret.comments = params.get("description", "")
+                if not vtes.VTES:
+                    vtes.VTES.load()
+                for item in result.fragment.split(";"):
+                    card, count = item.split("=", 1)
+                    count = int(count)
+                    if count <= 0:
+                        continue
+                    ret[vtes.VTES[int(card)]] = count
+                return ret
+            elif result.path.startswith("/decks/"):
+                return cls.from_vdb(result.path[7:])
+            raise ValueError("Unknown VDB URL format")
+        raise ValueError("Unknown deck URL provider")
+
     def check(self) -> bool:
         """Check a deck conforms to the rules IRT cards count
 
@@ -185,6 +225,14 @@ class Deck(collections.Counter):
                 )
         return utils.json_pack(ret)
 
+    def to_minimal_json(self) -> dict:
+        ret = {
+            "id": self.id,
+            "name": self.name,
+            "cards": {str(card.id): count for card, count in self.cards() if count},
+        }
+        return utils.json_pack(ret)
+
     def from_json(self, state) -> None:
         """Initialize from a JSON dict generated by the `to_json()` method."""
         self.id = state.get("id")
@@ -199,6 +247,9 @@ class Deck(collections.Counter):
         self.name = state.get("name")
         self.author = state.get("author")
         self.comments = state.get("comments")
+        for card_id, count in state.get("cards", {}).items():
+            c = vtes.VTES[int(card_id)]
+            self[c] = count
         for card in state.get("crypt", {}).get("cards", []):
             c = vtes.VTES[card["id"]]
             self[c] = card["count"]
@@ -437,7 +488,7 @@ class Deck(collections.Counter):
 
     def to_vdb(self) -> str:
         """Generating vdb.smeaa.casa link to deck"""
-        link = "https://vdb.smeea.casa/decks?"
+        link = "https://vdb.im/decks?"
         link += urllib.parse.urlencode(
             {
                 "name": self.name or "New KRCG Deck",
