@@ -4,6 +4,7 @@ It handles the legacy TWDA: many tricky formats used through this historic docum
 Only modifiy this file if you know what you're doing, and proceed with caution.
 """
 from typing import TextIO, Tuple
+import datetime
 import enum
 import logging
 import math
@@ -163,6 +164,7 @@ _DISCIPLINE_TRIGRAM = "|".join(
         "vic",
         "vin",
         "vis",
+        "viz",
     ]
 )
 _TITLE = "|".join(
@@ -199,6 +201,8 @@ _CLAN = "|".join(
         "akunanse",
         "brujah",
         "assamite",
+        "banu haqim",
+        "ministry",
         "follower of set",
         "brujah antitribu",
         "guruhi",
@@ -509,13 +513,22 @@ class Parser:
 
     def parse_twda_headers(self, index: int, line: str):
         """Parse a line of text for TWDA headers."""
-        if index < 4:
-            if index == 1:
-                self.deck.event = line
-            elif index == 2:
-                self.deck.place = line
-            elif index == 3:
+        if index == 1:
+            self.deck.event = line
+            return True
+        # third line should always be the date, but it has happened that some
+        # submissions lack this field, misformat it,
+        # or omit the location (2nd line) for online events
+        if not self.deck.date:
+            try:
                 self.deck.date = arrow.get(line, "MMMM Do YYYY").date()
+                return True
+            except arrow.parser.ParserMatchError:
+                if index == 3:
+                    self.logger.warning("Unable to parse date header: %s", line)
+                pass
+        if index == 2:
+            self.deck.place = line
             return True
         if not self.deck.tournament_format:
             try:
@@ -590,6 +603,11 @@ class Parser:
                 return True
             except AttributeError:
                 pass
+        # Always put a date, so if no date was parsed in headers,
+        # just put today as the date
+        if not self.deck.date:
+            self.deck.date = datetime.date.today()
+            self.logger.warning("No date found, using today")
 
     def get_card(self, line: str, twda: bool = False) -> Tuple[object, int]:
         """Try to find a card and count, register possible comment."""
@@ -601,6 +619,15 @@ class Parser:
         if match:
             name = match.group("name")
             count = int(match.group("ante_count") or 0)
+            # get the group from the crypt tail
+            group = None
+            tail = match.group("crypt_tail")
+            if tail:
+                try:
+                    group = int(tail[-1])
+                except ValueError:
+                    pass
+
         if name:
             if not count:
                 # do not match name with no count prefix during the preface
@@ -618,9 +645,18 @@ class Parser:
                         if name.strip(" :()[]-_*=") in _DISCIPLINES:
                             self.logger.warning('improper discipline "%s"', line)
                             return None, 0
+            # for evolutions (eg. Theo Bell (G6)) the name in TWDA
+            # might not contain the group, we need to rely on the group in crypt tail
+            if name and group and name[-1] != ")":
+                name += f" (g{group})"
             try:
                 card = vtes.VTES[name]
-                if name == "raven" and card.name == "Camille Devereux, The Raven":
+                # special case for Camille / Raven to keep them distinct if the decklist
+                # predates the merge of the two crypt cards
+                if (
+                    name in ["raven", "raven (g1)"]
+                    and card.name == "Camille Devereux, The Raven (G1)"
+                ):
                     self.deck.raven = count
             except KeyError:
                 count = 0
